@@ -29,8 +29,9 @@
 
 #include "Environment.h"
 
-#include <stdio.h>
-#include <stdarg.h>
+#include <cstdio>
+#include <cstdarg>
+#include <cstdlib>
 
 using namespace std;
 
@@ -51,57 +52,6 @@ Environment& Environment::get() throw ()
 
 // Initialize the environment with default values
 Environment::Environment() throw ()
-	: _iface("eth0"), _defprof("none"), _verbose(false), _debug(false), _timeout(5), _init_timeout(3) {}
-
-void fatal_error(const char* fmt, ...) throw() ATTR_PRINTF(1, 2)
-{
-	fprintf(stderr, "guessnet: ");
-	va_list ap;
-	va_start(ap, fmt);
-	vfprintf(stderr, fmt, ap);
-	va_end(ap);
-	fprintf(stderr, "\n");
-	exit(1);
-}
-
-void error(const char* fmt, ...) throw() ATTR_PRINTF(1, 2)
-{
-	va_list ap;
-	va_start(ap, fmt);
-	vfprintf(stderr, fmt, ap);
-	va_end(ap);
-}
-
-void warning(const char* fmt, ...) throw() ATTR_PRINTF(1, 2)
-{
-	va_list ap;
-	va_start(ap, fmt);
-	vfprintf(stderr, fmt, ap);
-	va_end(ap);
-}
-
-void verbose(const char* fmt, ...) throw() ATTR_PRINTF(1, 2)
-{
-	if (Environment::get().verbose())
-	{
-		va_list ap;
-		va_start(ap, fmt);
-		fprintf(stderr, "guessnet: ");
-		vfprintf(stderr, fmt, ap);
-		va_end(ap);
-	}
-}
-
-void debug(const char* fmt, ...) throw() ATTR_PRINTF(1, 2)
-{
-	if (Environment::get().debug())
-	{
-		va_list ap;
-		va_start(ap, fmt);
-		fprintf(stderr, "guessnet: ");
-		vfprintf(stderr, fmt, ap);
-		va_end(ap);
-	}
-}
+	: _iface("eth0"), _defprof("none"), _timeout(5), _init_timeout(3) {}
 
 // vim:set ts=4 sw=4:
