@@ -1,7 +1,9 @@
 #include "Environment.h"
+#include "util/output.h"
 #include "IFace.h"
 
-#include <stdio.h>
+#include <cstdio>
+#include <cstdlib>
 
 static void printConfig(const char* tag, IFace& iface)
 {
